@@ -12,7 +12,7 @@ const SCREEN_HEIGHT: u32 = 600;
 
 fn main() {
     let a = app::App::default();
-    let mut win = window::GlutWindow::new(100, 100, SCREEN_WIDTH as _, SCREEN_HEIGHT as _, None);
+    let mut win = window::GlWindow::new(100, 100, SCREEN_WIDTH as _, SCREEN_HEIGHT as _, None);
     win.set_mode(Mode::Opengl3);
     win.end();
     win.make_resizable(true);
@@ -22,24 +22,27 @@ fn main() {
     let (painter, egui_input_state) = egui_backend::with_fltk(&mut win, DpiScaling::Custom(1.5));
     let mut egui_ctx = egui::CtxRef::default();
 
-    let state_rc = Rc::from(RefCell::from(egui_input_state));
-    let painter_rc = Rc::from(RefCell::from(painter));
-    let state = state_rc.clone();
-    let painter = painter_rc.clone();
-    win.handle(move |win, ev| match ev {
-        enums::Event::Push
-        | enums::Event::Released
-        | enums::Event::KeyDown
-        | enums::Event::KeyUp
-        | enums::Event::MouseWheel
-        | enums::Event::Resize
-        | enums::Event::Move
-        | enums::Event::Drag => {
-            let mut state = state.borrow_mut();
-            state.fuse_input(win, ev, &mut painter.borrow_mut());
-            true
+    let state = Rc::from(RefCell::from(egui_input_state));
+    let painter = Rc::from(RefCell::from(painter));
+
+    win.handle({
+        let state = state.clone();
+        let painter = painter.clone();
+        move |win, ev| match ev {
+            enums::Event::Push
+            | enums::Event::Released
+            | enums::Event::KeyDown
+            | enums::Event::KeyUp
+            | enums::Event::MouseWheel
+            | enums::Event::Resize
+            | enums::Event::Move
+            | enums::Event::Drag => {
+                let mut state = state.borrow_mut();
+                state.fuse_input(win, ev, &mut painter.borrow_mut());
+                true
+            }
+            _ => false,
         }
-        _ => false,
     });
 
     let start_time = Instant::now();
@@ -48,8 +51,8 @@ fn main() {
     let mut quit = false;
 
     while a.wait() {
-        let mut state = state_rc.borrow_mut();
-        let mut painter = painter_rc.borrow_mut();
+        let mut state = state.borrow_mut();
+        let mut painter = painter.borrow_mut();
         state.input.time = Some(start_time.elapsed().as_secs_f64());
         egui_ctx.begin_frame(state.input.take());
 
@@ -79,13 +82,13 @@ fn main() {
             }
         });
 
-        let (egui_output, paint_cmds) = egui_ctx.end_frame();
+        let (egui_output, shapes) = egui_ctx.end_frame();
         state.fuse_output(&mut win, &egui_output);
 
-        let paint_jobs = egui_ctx.tessellate(paint_cmds);
+        let meshes = egui_ctx.tessellate(shapes);
 
         //Draw egui texture
-        painter.paint_jobs(None, paint_jobs, &egui_ctx.texture());
+        painter.paint_jobs(None, meshes, &egui_ctx.texture());
 
         win.swap_buffers();
         win.flush();
