@@ -15,18 +15,19 @@ fn main() {
     app::get_system_colors();
     app::set_font_size(20);
     let mut main_win = window::Window::new(100, 100, SCREEN_WIDTH as _, SCREEN_HEIGHT as _, None);
-    let mut glut_win = window::GlutWindow::new(5, 5, main_win.w() - 200, main_win.h() - 10, None);
-    glut_win.set_mode(Mode::Opengl3);
-    glut_win.end();
+    let mut gl_win = window::GlWindow::new(5, 5, main_win.w() - 200, main_win.h() - 10, None);
+    gl_win.set_mode(Mode::Opengl3);
+    gl_win.end();
     let mut col = group::Flex::default()
         .column()
         .with_size(185, 590)
-        .right_of(&glut_win, 5);
+        .right_of(&gl_win, 5);
     col.set_frame(FrameType::DownBox);
     let mut frm = frame::Frame::default();
     frm.set_color(Color::Red.inactive());
     frm.set_frame(FrameType::FlatBox);
     let mut slider = valuator::Slider::default().with_type(valuator::SliderType::HorizontalFill);
+    slider.clear_visible_focus();
     slider.set_slider_frame(FrameType::RFlatBox);
     slider.set_slider_size(0.20);
     slider.set_color(Color::Blue.inactive());
@@ -36,18 +37,19 @@ fn main() {
     main_win.end();
     main_win.make_resizable(true);
     main_win.show();
-    glut_win.make_current();
+    gl_win.make_current();
 
     let (painter, egui_input_state) =
-        egui_backend::with_fltk(&mut glut_win, DpiScaling::Custom(1.5));
+        egui_backend::with_fltk(&mut gl_win, DpiScaling::Custom(1.5));
     let mut egui_ctx = egui::CtxRef::default();
 
-    let state_rc = Rc::from(RefCell::from(egui_input_state));
-    let painter_rc = Rc::from(RefCell::from(painter));
-    let state = state_rc.clone();
-    let painter = painter_rc.clone();
+    let state = Rc::from(RefCell::from(egui_input_state));
+    let painter = Rc::from(RefCell::from(painter));
+
     main_win.handle({
-        let mut w = glut_win.clone();
+        let state = state.clone();
+        let painter = painter.clone();
+        let mut w = gl_win.clone();
         move |_, ev| match ev {
             enums::Event::Push
             | enums::Event::Released
@@ -71,8 +73,8 @@ fn main() {
     let mut quit = false;
 
     while a.wait() {
-        let mut state = state_rc.borrow_mut();
-        let mut painter = painter_rc.borrow_mut();
+        let mut state = state.borrow_mut();
+        let mut painter = painter.borrow_mut();
         state.input.time = Some(start_time.elapsed().as_secs_f64());
         egui_ctx.begin_frame(state.input.take());
         frm.set_label(&format!("Hello {}", &name));
@@ -105,16 +107,16 @@ fn main() {
             }
         });
 
-        let (egui_output, paint_cmds) = egui_ctx.end_frame();
-        state.fuse_output(&mut glut_win, &egui_output);
+        let (egui_output, shapes) = egui_ctx.end_frame();
+        state.fuse_output(&mut gl_win, &egui_output);
 
-        let paint_jobs = egui_ctx.tessellate(paint_cmds);
+        let meshes = egui_ctx.tessellate(shapes);
 
         //Draw egui texture
-        painter.paint_jobs(None, paint_jobs, &egui_ctx.texture());
+        painter.paint_jobs(None, meshes, &egui_ctx.texture());
 
-        glut_win.swap_buffers();
-        glut_win.flush();
+        gl_win.swap_buffers();
+        gl_win.flush();
         app::sleep(0.006);
         app::awake();
         if quit {
