@@ -283,6 +283,24 @@ impl Painter {
         id
     }
 
+    /// Creates a new user texture from rgba8
+    pub fn new_user_texture_rgba8(
+        &mut self,
+        size: (usize, usize),
+        rgba8_pixels: Vec<u8>,
+        filtering: bool,
+    ) -> egui::TextureId {
+        let id = egui::TextureId::User(self.user_textures.len() as u64);
+        self.user_textures.push(Some(UserTexture {
+            size,
+            pixels: rgba8_pixels,
+            texture: None,
+            filtering,
+            dirty: true,
+        }));
+        id
+    }
+
     fn upload_egui_texture(&mut self, texture: &Texture) {
         if self.egui_texture_version == Some(texture.version) {
             return; // No change
@@ -423,7 +441,29 @@ impl Painter {
         }
     }
 
-    /// Frees the user texture
+    /// Updates texture rgba8 data
+    pub fn update_user_texture_rgba8_data(
+        &mut self,
+        texture_id: egui::TextureId,
+        rgba8_pixels: Vec<u8>,
+    ) {
+        match texture_id {
+            egui::TextureId::Egui => {}
+            egui::TextureId::User(id) => {
+                let id = id as usize;
+                if id < self.user_textures.len() {
+                    if let Some(user_textures) = self.user_textures[id].as_mut() {
+                        user_textures.pixels = rgba8_pixels;
+                        user_textures.dirty = true
+                    }
+                }
+            }
+        }
+    }
+
+    /// Frees the user texture,
+    /// 
+    /// fn free_user_texture() and fn free() implemented from epi both are basically the same. 
     pub fn free_user_texture(&mut self, id: egui::TextureId) {
         if let egui::TextureId::User(id) = id {
             let idx = id as usize;
@@ -433,9 +473,9 @@ impl Painter {
                     ..
                 }) = self.user_textures[idx].as_mut()
                 {
-                    unsafe { gl::DeleteTextures(1, texture) }
+                    unsafe { gl::DeleteTextures(1, &*texture) }
                 }
-                self.user_textures[idx] = None
+                self.user_textures[idx] = None;
             }
         }
     }
@@ -511,8 +551,6 @@ impl Painter {
                     );
 
                     self.paint_mesh(&mesh);
-                } else {
-                    continue;
                 }
             }
 
@@ -670,6 +708,20 @@ impl Painter {
     }
 }
 
+impl epi::TextureAllocator for Painter {
+    fn alloc_srgba_premultiplied(
+        &mut self,
+        size: (usize, usize),
+        srgba_pixels: &[egui::Color32],
+    ) -> egui::TextureId {
+        self.new_user_texture(size, srgba_pixels, true)
+    }
+
+    fn free(&mut self, id: egui::TextureId) {
+        self.free_user_texture(id)
+    }
+}
+
 impl Drop for Painter {
     fn drop(&mut self) {
         self.cleanup()
